Welcome to VillageWars!

Here's some info on how to play this game successfully.

First, you need to install python. To download the installer, visit this link: https://www.python.org/ftp/python/3.10.6/python-3.10.6-amd64.exe
If python is already installed, move on.

When running the server for VillageWars, the computer has to access and give information through port 5555. If you can customize your firewall to let this port be used by python, then great. Otherwise you'll have to turn off the firewall temporarily while running the server.

You should be good to go!

Quickstart:

>import villagewars
>villagewars.download('C://Users/aamcc/Desktop/')

Go inside the VillageWars folder that was created and you'll see the current version as a folder. Go inside that and double-click "main.pyw" to start the client.
To run a server, go throught the src folder and double-click the "VillageWarsServer.py".

